@@ -1,9 +1,4 @@
 # -*- coding: utf-8 -*-
-'''
-Created on Nov 19, 2013
-
-@author: Ricardo Silva
-'''
 
 PAGSEGURO_ACCOUNT_EMAIL = 'contato@pizze.me'
 PAGSEGURO_TOKEN = 'F36ADE4A0F3D4AB8A96E968D486CA0D4'
